import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk._jsii
import cdk_iam_floyd._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-ssm-document", "3.1.0", __name__[0:-6], "cdk-ssm-document@3.1.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
